$title Strommarkt

$onText


Strommarkt-Modell:

Minimierung der Gesamtkosten der Stromerzeugung (Stromgestehungskosten).



Annahmen Angebotsseite:

- Jeder Kraftwerkstyp i bzw. j erzeugt zu jeder Stunde h die Strommenge x bzw. y zu geringstmöglichen und
  konstanten Kosten (Gestehungskosten g bzw. f --> exogen vorgegeben).

- Jeder Kraftwerkstyp besitzt eine maximale Kapazität a bzw. b (exogen vorgegeben) pro Std h, welche abhängig von
  externen Faktoren (z.B. Wind oder Sonneneinstrahlung) zu jeder Stunde h zu einem bestimmten
  Anteil ausgelastet werden kann (Verfügbarkeit li bzw. lj --> exogen vorgegeben).
  
- Speziell Speicher: Es kann nur solange Strom geliefert werden, bis der Speicher leer ist (NB5). 

- Das maximale Stromangebot der Kraftwerke i und j besteht zu jeder gegebenen Stunde h aus
  dem Produkt der maximalen Stunden-Kapazität a bzw. b und der Stunden-Verfügbarkeit li bzw. lj. 
  
- Speziell Batterie: Das Set besteht aus 2 Elementen
  --> Einspeisung = Batterie aufladen (Wasser füllen) --> Strom wird dem Netz entnommen. 
  --> Ausspeisung = Batterie entladen (Wasser entleeren) --> Strom wird dem Netz hinzugefügt. 
  
- Die unterschiedlichen Start-Up Zeiten (und Kosten) der verschiedenen Kraftwerkstypen werden
  in diesem Modell nicht berücksichtigt.

- Netzrestriktionen werden in diesem Modell nicht berücksichtigt.



Annahmen Nachfrageseite:

- Die zukünftige Stromnachfrage bzw. das Lastprofil wird mit Hilfe von Szenarien exogen abgebildet.

- In die Lastprofil-Szenarien werden unterschiedliche Annahmen über das Ladeverhalten (und andere Verbrauchsmuster)
  und die damit einhergehenden Schwankungen der Nachfrage eingebettet.


  ZIELFUNKTION
- Die tatsächlich gelieferte Menge Strom x pro Kraftwerk i und der Batterie y(Ausspeisung) pro Stunde h ergibt
  sich aus dem Modell bzw. aus der Minimierung der Gesamtkosten.
  
  Die Gesamtkosten entsprechen der Summe des Produktes aus Gestehungskosten g und f,
  der tatsächlich gelieferten Menge Strom x und y der Kraftwerke i und j über alle Stunden h.

  NEBENBEDINGUNG 1
- Die Summe der tatsächlich gelieferten Menge Strom x aller Kraftwerkstypen i pro Stunde h
  muss kleiner als das Angebot (MaxKap * Verfügbarkeit) sein.

  NEBENBEDINGUNG 2
- Die Summe der tatsächlich gelieferten Menge Strom y aller Kraftwerkstypen j pro Stunde h
  muss kleiner als das Angebot (MaxKap * Verfügbarkeit) sein.

  NEBENBEDINGUNG 3
- Die Nachfrage entspricht der gelieferten Menge Strom + Batterie-Ausspeisung bzw. - Batterie-Einspeisung.
  
  NEBENBEDINGUNG 4
- Das Batterie-Level (Ladestatus) entspricht dem vorherigen Batterie-Level + Einspeisung bzw. - Ausspeisung.
  Das Start-Level der Batterie wird über den $-Befehl hinzugefügt.
  
  NEBENBEDINGUNG 5
- Die Summe über alle Stunden h des gelieferten Stroms aus PumpspeicherKW darf dessen Jahreskapazität
  nicht übersteigen. 



Abkürzungen:
  KW            --> Kraftwerke
  Std           --> Stunden
  KWh           --> Kilowattstunde


Stunden:

    1      24.00 - 05.00 Uhr    Nacht
    2      05.00 - 07.00 Uhr    Morgenfrüh
    3      07.00 - 09.00 Uhr    Morgen  
    4      09.00 - 11.00 Uhr    Später Morgen
    5      11.00 - 13.00 Uhr    Mittag
    6      13.00 - 15.00 Uhr    Früher Nachmittag
    7      15.00 - 17.00 Uhr    Nachmittag
    8      17.00 - 19.00 Uhr    Früher Abend
    9      19.00 - 21.00 Uhr    Abend
   10      21.00 - 24.00 Uhr    Nacht


$offText



Set

       i        'Kraftwerke'            / Solar, Speicher, Gas /
       j        'Batterie'              / Einspeisung, Ausspeisung /
       h        'Stunden'               / 1*10 /  ;



Parameter

     a(i) 'Max. Stunden-Kapazität KW i unter Volllast in KWh'
   
        / Solar                 20
          Speicher              10
          Gas                   10 /  ;
          


Parameter

     b(j) 'Max. Stunden-Kapazität Batterie --> Einspeisung=Füllen / Ausspeisung=Entleeren'
   
        / Einspeisung            10
          Ausspeisung            10 /  ;



Table

     li(h,i) 'Verfügbarkeit von KW i zur Stunde h zwischen 0 und 100% (Abhängig von äusseren Faktoren wie Wetter)'

                    Solar    Speicher    Gas    
     1              0.00        1         1
     2              0.05        1         1   
     3              0.15        1         1   
     4              0.40        1         1
     5              0.90        1         1
     6              0.75        1         1
     7              0.60        1         1
     8              0.40        1         1
     9              0.10        1         1
    10              0.00        1         1  ;



Table

     lj(h,j) 'Verfügbarkeit der Batterie j zur Stunde h zwischen 0 und 100% (Abhängig von äusseren Faktoren wie Wetter)'

                 Einspeisung         Ausspeisung    
     1                1                   1
     2                1                   1  
     3                1                   1   
     4                1                   1
     5                1                   1
     6                1                   1
     7                1                   1
     8                1                   1
     9                1                   1
    10                1                   1  ;



Parameter

     g(i) 'Stromgestehungskosten KW i in Fr./ KWh'
   
        / Solar                 0.05
          Speicher              0.10
          Gas                   0.20 /  ;



Parameter

     f(j) 'Stromgestehungskosten KW j in Fr./ KWh'
   
        / Einspeisung           0.00
          Ausspeisung           0.00 /  ;
          


Parameter

     d(h) 'Nachfrage zur Std h'
   
        / 1                        2
          2                        5
          3                        8
          4                       10
          5                       12
          6                       10
          7                        8
          8                       14
          9                       12
         10                        8 /  ;

    

Variables

     z            'Gesamtkosten des gelieferten Stroms'  ;



Positive Variable

     x(h,i)       'Gelieferte Menge Strom von KW i zur Std h'
     y(h,j)       'Strommenge --> Einspeisung Batterie'
     Q(h)         'Batterielevel bzw. Füllstand' ;
    
     Q.up(h) = 20  ;
     
$onText
     Q(h)         'Batterielevel bzw. Füllstand' /10.lo 5/      --> Def. der letzter Periode per Variable Attribute, aber
                   die folgende Formulierung macht mehr Sinn da automatisch das letzte Element des Sets definiert wird.

 Q.lo(h) $ (ord(h) = card(h)) = 10 ;
$offText



Equation

    Gesamtkosten                    'Zielfkt:  Min. Gesamtkosten'
    
    MaxKapKW(h,i)                   'NB1:  Gelieferte Menge Strom pro KW i und Std h ≤ Verfügbarkeit zur Std h'
     
    MaxKapBat(h,j)                  'NB2:  Gelieferte Menge Strom aus Batterie pro Std h ≤ Verfügbarkeit zur Std h'
 
    Demand(h)                       'NB3:  Nachfrage = gelieferten Menge Strom + Ausspeisung bzw. - Einspeisung'

    BatterieLevel(h)                'NB4:  Batterie Level pro Stunde'
    
    MaxKapSpeicher(i)               'NB5:  Die Summe der gelieferten Menge Strom über alle Stunden aus Speicher ≤ Max. Kapazität von Speicher' ;



    Gesamtkosten..                  z           =e=  sum((h,i), g(i) * x(h,i)) + sum((h,j), f(j) * y(h,j)) ;

    MaxKapKW(h,i)..                 x(h,i)      =l=  a(i) * li(h,i) ;

    MaxKapBat(h,j)..                y(h,j)      =l=  b(j) * lj(h,j) ;

    Demand(h)..                     d(h)        =e=  sum(i, x(h,i)) + y(h,"Ausspeisung") - y(h,"Einspeisung") ;
   
    BatterieLevel(h)..              Q(h)        =e=  Q(h--1) + y(h,"Einspeisung") * 0.95 - y(h,"Ausspeisung") ;                       
                                         
    MaxKapSpeicher("Speicher")..    sum(h, x(h,"Speicher"))  =l=  15 ;
    


Model Strommarkt / all / ;


solve Strommarkt using lp minimizing z ;


display x.l, x.m ;

